# Email Manager

Manages email templates for Drupal emails, allowing customization via an admin interface, with support for tokens, HTML emails, and a WYSIWYG editor.

## Features
- Manage email templates for Drupal emails sent via hook_mail().
- Customize email subject, body, and headers via an admin interface.
- Support tokens in email subject and body (requires the `token` module).
- Send HTML emails with WYSIWYG editing support using CKEditor.
- Dynamically discover email keys from hook_mail() implementations.
- Define email keys manually via an admin UI or in a configuration file.
- Admin configuration at Configuration > System > Email Templates.
- Drupal 12 readiness for future compatibility.

## Requirements
- Drupal 10.3, 11.0, or 12.0 (future-compatible).
- PHP 8.1 or higher (Drupal 10/11 requirement).
- Drupal modules: `node`, `token`, `editor`, `ckeditor` (included as dependencies).

## Installation
1. Install via Composer:
  ```bash
  composer require 'drupal/email_manager:^1.0'
2. Enable the module:
  ```bash
  drush en email_manager -y
3. Clear caches:
  ```bash
  drush cr

## Configuration
- Navigate to **Configuration > System > Email Templates** (`/admin/config/system/email-manager`).
- Add or edit email templates:
  -- Select an email key from the dropdown (discovered dynamically or defined manually).
  -- Customize the subject and body, using tokens if available.
  -- Enable HTML email support and use the WYSIWYG editor for formatting.
- Manage email keys at **Configuration > System > Email Keys** (`/admin/config/system/email-manager/keys`):
  -- Add custom email keys if not detected automatically.

## Usage
- Create a Template:
  -- Go to /admin/config/system/email-manager/add.
  -- Select an email key, define the subject and body, and save.

- Send Emails:
  -- Emails sent via Drupal’s mail system will use the configured templates.
  -- Check logs for errors:
    ```bash
    drush watchdog:show --type=email_manager

## Notes for the Contact Module
Automatic email key discovery via hook_mail() is not supported for the core contact module due to compatibility issues. To manage email templates for the contact module, you can:
  - Define keys manually at /admin/config/system/email-manager/keys.
  - Declare keys in a configuration file named contact.email_manager.yml in the contact module’s directory (requires a patch to core):
yaml
email_keys:
  contact_message: 'Contact Message'
  page_copy: 'Page Copy'
  user_copy: 'User Copy'



## For Contributors: Declaring Email Keys
To ensure Email Manager accurately detects your module’s email keys, you can declare them in a configuration file named `your_module.email_manager.yml` in your module’s root directory. Example:
```email_keys:
  custom_email: 'Custom Email'
  another_email: 'Another Email'
  ```
This method is preferred as it avoids runtime discovery issues. If your module cannot declare keys this way, Email Manager will attempt to discover them dynamically via hook_mail(), but this may not capture all keys (e.g., those defined in conditional logic). You can also manually define keys at `/admin/config/system/email-manager/keys`.


## Testing
- Automated Tests:
  ```bash
  ./vendor/bin/phpunit -c web/core modules/custom/email_manager/tests/src/Functional

- Manual Testing:
  -- Verify email template creation with token replacement and HTML formatting.
  -- Test email key discovery and manual key addition.


## Contributing
See CONTRIBUTING.md for guidelines on reporting issues, submitting patches, and becoming a co-maintainer.

## Maintainers
Bhavin Joshi - https://bhj.im/do

## Issues
Report bugs or request features in the Drupal.org issue queue


