<?php

namespace Drupal\email_manager\Controller;

use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\Url;

/**
 * Controller for email template management.
 */
class EmailTemplateController extends ControllerBase {

  /**
   * Lists all email templates.
   *
   * @return array
   *   A render array for the template list.
   */
  public function listTemplates() {
    // Get the list builder for the email_template entity.
    $list_builder = $this->entityTypeManager()->getListBuilder('email_template');

    // Build the render array.
    $build = [
      '#type' => 'container',
      'add_link' => [
        '#type' => 'link',
        '#title' => $this->t('Add email template'),
        '#url' => Url::fromRoute('email_manager.template_add'),
        '#attributes' => [
          'class' => ['button', 'button--primary'],
        ],
      ],
      'table' => $list_builder->render(),
    ];

    return $build;
  }

  /**
   * Provides the form for adding a new email template.
   *
   * @return array
   *   A render array for the email template form.
   */
  public function addTemplateForm() {
    // Create a new email template entity.
    $template = $this->entityTypeManager()->getStorage('email_template')->create([]);

    // Build the form with the new entity.
    return $this->entityFormBuilder()->getForm($template, 'add');
  }
}
