<?php

namespace Drupal\email_manager;

use Drupal\Core\Config\Entity\ConfigEntityListBuilder;
use Drupal\Core\Entity\EntityInterface;
use Drupal\Core\Url;

/**
 * Provides a listing of email keys.
 */
class EmailKeyListBuilder extends ConfigEntityListBuilder {

  /**
   * Builds the header for the email key list table.
   *
   * @return array
   *   An array of header labels.
   */
  public function buildHeader() {
    $header['label'] = $this->t('Label');
    $header['module'] = $this->t('Module');
    $header['key'] = $this->t('Email Key');
    return $header + parent::buildHeader();
  }

  /**
   * Builds a row for an email key entity in the list table.
   *
   * @param \Drupal\Core\Entity\EntityInterface $entity
   *   The email key entity.
   *
   * @return array
   *   An array of row data.
   */
  public function buildRow(EntityInterface $entity) {
    $row['label'] = $entity->label();
    $row['module'] = $entity->get('module');
    $row['key'] = $entity->get('key');
    return $row + parent::buildRow($entity);
  }

  /**
   * Builds the render array for the email key list.
   *
   * @return array
   *   A render array for the list.
   */
  public function render() {
    $build = parent::render();

    if (empty($build['table']['#rows'])) {
      $build['table']['#empty'] = $this->t('There are no email keys defined yet. <a href=":url">Add an email key</a>.', [
        ':url' => Url::fromRoute('email_manager.key_add')->toString(),
      ]);
    }

    return $build;
  }
}
