<?php

namespace Drupal\email_manager\Entity;

use Drupal\Core\Config\Entity\ConfigEntityBase;

/**
 * Defines the Email Key configuration entity.
 *
 * @ConfigEntityType(
 *   id = "email_key",
 *   label = @Translation("Email Key"),
 *   handlers = {
 *     "list_builder" = "Drupal\email_manager\EmailKeyListBuilder",
 *     "form" = {
 *       "add" = "Drupal\email_manager\Form\EmailKeyForm",
 *       "edit" = "Drupal\email_manager\Form\EmailKeyForm",
 *       "delete" = "Drupal\Core\Entity\EntityDeleteForm"
 *     }
 *   },
 *   config_prefix = "email_key",
 *   admin_permission = "administer email templates",
 *   entity_keys = {
 *     "id" = "id",
 *     "label" = "label"
 *   },
 *   links = {
 *     "add-form" = "/admin/config/system/email-manager/keys/add",
 *     "edit-form" = "/admin/config/system/email-manager/keys/{email_key}/edit",
 *     "delete-form" = "/admin/config/system/email-manager/keys/{email_key}/delete",
 *     "collection" = "/admin/config/system/email-manager/keys"
 *   },
 *   config_export = {
 *     "id",
 *     "label",
 *     "module",
 *     "key"
 *   }
 * )
 */
class EmailKey extends ConfigEntityBase {

  /**
   * The email key ID.
   *
   * @var string
   */
  protected $id;

  /**
   * The email key label.
   *
   * @var string
   */
  protected $label;

  /**
   * The module providing the email.
   *
   * @var string
   */
  protected $module;

  /**
   * The email key.
   *
   * @var string
   */
  protected $key;
}
