<?php

namespace Drupal\email_manager\Entity;

use Drupal\Core\Config\Entity\ConfigEntityBase;

/**
 * Defines the Email Template configuration entity.
 *
 * @ConfigEntityType(
 *   id = "email_template",
 *   label = @Translation("Email Template"),
 *   handlers = {
 *     "list_builder" = "Drupal\email_manager\EmailTemplateListBuilder",
 *     "form" = {
 *       "add" = "Drupal\email_manager\Form\EmailTemplateForm",
 *       "edit" = "Drupal\email_manager\Form\EmailTemplateForm",
 *       "delete" = "Drupal\Core\Entity\EntityDeleteForm"
 *     }
 *   },
 *   config_prefix = "email_template",
 *   admin_permission = "administer email templates",
 *   entity_keys = {
 *     "id" = "id",
 *     "label" = "label"
 *   },
 *   links = {
 *     "add-form" = "/admin/config/system/email-manager/add",
 *     "edit-form" = "/admin/config/system/email-manager/{email_template}/edit",
 *     "delete-form" = "/admin/config/system/email-manager/{email_template}/delete",
 *     "collection" = "/admin/config/system/email-manager"
 *   },
 *   config_export = {
 *     "id",
 *     "label",
 *     "module",
 *     "key",
 *     "subject",
 *     "body",
 *     "headers",
 *     "is_html"
 *   }
 * )
 */
class EmailTemplate extends ConfigEntityBase {

  /**
   * The template ID.
   *
   * @var string
   */
  protected $id;

  /**
   * The template label.
   *
   * @var string
   */
  protected $label;

  /**
   * The module providing the email.
   *
   * @var string
   */
  protected $module;

  /**
   * The email key.
   *
   * @var string
   */
  protected $key;

  /**
   * The email subject.
   *
   * @var string
   */
  protected $subject;

  /**
   * The email body.
   *
   * @var string
   */
  protected $body;

  /**
   * The email headers.
   *
   * @var array
   */
  protected $headers = [];

  /**
   * Whether the email is in HTML format.
   *
   * @var bool
   */
  protected $is_html = FALSE;

}
