<?php

namespace Drupal\email_manager\Form;

use Drupal\Core\Entity\EntityForm;
use Drupal\Core\Form\FormStateInterface;

/**
 * Form for creating and editing email keys.
 */
class EmailKeyForm extends EntityForm {

  /**
   * Builds the form for creating or editing an email key.
   *
   * @param array $form
   *   An associative array containing the structure of the form.
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   *   The current state of the form.
   *
   * @return array
   *   The form structure.
   */
  public function form(array $form, FormStateInterface $form_state) {
    $form = parent::form($form, $form_state);
    $email_key = $this->entity;

    $form['label'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Label'),
      '#default_value' => $email_key->label(),
      '#required' => TRUE,
    ];

    $form['id'] = [
      '#type' => 'machine_name',
      '#default_value' => $email_key->id(),
      '#machine_name' => [
        'exists' => '\Drupal\email_manager\Entity\EmailKey::load',
      ],
      '#disabled' => !$email_key->isNew(),
    ];

    $form['module'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Module'),
      '#default_value' => $email_key->get('module'),
      '#description' => $this->t('The module providing the email (e.g., user, contact).'),
      '#required' => TRUE,
    ];

    $form['key'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Email Key'),
      '#default_value' => $email_key->get('key'),
      '#description' => $this->t('The email key used in hook_mail (e.g., password_reset).'),
      '#required' => TRUE,
    ];

    return $form;
  }

  /**
   * Saves the email key entity.
   *
   * @param array $form
   *   An associative array containing the structure of the form.
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   *   The current state of the form.
   */
  public function save(array $form, FormStateInterface $form_state) {
    $email_key = $this->entity;
    $status = $email_key->save();

    $message = $status == SAVED_NEW
      ? $this->t('Created email key %label.', ['%label' => $email_key->label()])
      : $this->t('Updated email key %label.', ['%label' => $email_key->label()]);
    \Drupal::messenger()->addStatus($message);

    $form_state->setRedirectUrl($email_key->toUrl('collection'));
  }
}
